@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -43,13 +43,13 @@ void PrintQueue::showQueues(const QStringList &queues, const QString &cwd)
     Q_UNUSED(cwd)
 
     if (!queues.isEmpty()) {
-        foreach (const QString & queue, queues) {
+        for (const QString &queue : queues) {
             showQueue(queue);
         }
     } else {
         qDebug() << "called with no args";
         // If DBus called the ui list won't be empty
-        QTimer::singleShot(500, this, SLOT(removeQueue()));
+        QTimer::singleShot(500, this, &PrintQueue::removeQueue);
     }
 }
 
@@ -60,12 +60,9 @@ void PrintQueue::showQueue(const QString &destName)
         // Reserve this since the CUPS call might take a long time
         m_uis[destName] = 0;
 
-        QStringList attr;
-        attr << KCUPS_PRINTER_NAME;
-        attr << KCUPS_PRINTER_TYPE;
         // Get destinations with these attributes
         QPointer<KCupsRequest> request = new KCupsRequest;
-        request->getPrinters(attr);
+        request->getPrinters({ KCUPS_PRINTER_NAME, KCUPS_PRINTER_TYPE });
         request->waitTillFinished();
         if (!request) {
             return;
@@ -73,10 +70,10 @@ void PrintQueue::showQueue(const QString &destName)
 
         bool found = false;
         KCupsPrinter printer;
-        KCupsPrinters printers = request->printers();
-        for (int i = 0; i < printers.size(); i++) {
-            if (printers.at(i).name() == destName) {
-                printer = printers.at(i);
+        const KCupsPrinters printers = request->printers();
+        for (const KCupsPrinter &printerItem : printers) {
+            if (printerItem.name() == destName) {
+                printer = printerItem;
                 found = true;
                 break;
             }
@@ -84,7 +81,7 @@ void PrintQueue::showQueue(const QString &destName)
         request->deleteLater();
 
         if (found) {
-            PrintQueueUi *ui = new PrintQueueUi(printer);
+            auto ui = new PrintQueueUi(printer);
             connect(ui, &PrintQueueUi::finished, this, &PrintQueue::removeQueue);
             ui->show();
             m_uis[printer.name()] = ui;
@@ -109,7 +106,7 @@ void PrintQueue::showQueue(const QString &destName)
 
 void PrintQueue::removeQueue()
 {
-    QWidget *ui = qobject_cast<QWidget*>(sender());
+    auto ui = qobject_cast<QWidget*>(sender());
     if (ui) {
         m_uis.remove(m_uis.key(ui));
     }
@@ -120,3 +117,5 @@ void PrintQueue::removeQueue()
          quit();
     }
 }
+
+#include "moc_PrintQueue.cpp"
