@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,10 +32,10 @@
 #include <QToolBar>
 #include <QMenu>
 #include <QByteArray>
-#include <QStringBuilder>
 #include <QProcess>
 #include <QDebug>
 #include <QPointer>
+#include <QShortcut>
 
 #include <KMessageBox>
 #include <KIconLoader>
@@ -48,10 +48,7 @@
 PrintQueueUi::PrintQueueUi(const KCupsPrinter &printer, QWidget *parent) :
     QDialog(parent),
     ui(new Ui::PrintQueueUi),
-    m_destName(printer.name()),
-    m_preparingMenu(false),
-    m_printerPaused(false),
-    m_lastState(0)
+    m_destName(printer.name())
 {
     ui->setupUi(this);
 
@@ -92,7 +89,7 @@ PrintQueueUi::PrintQueueUi(const KCupsPrinter &printer, QWidget *parent) :
     m_printerIcon = printer.icon().pixmap(PRINTER_ICON_SIZE, PRINTER_ICON_SIZE);
     ui->iconL->setPixmap(m_printerIcon);
 
-    m_pauseIcon = KIconLoader::global()->loadIcon("media-playback-pause",
+    m_pauseIcon = KIconLoader::global()->loadIcon(QLatin1String("media-playback-pause"),
                                                   KIconLoader::NoGroup,
                                                   KIconLoader::SizeMedium,
                                                   KIconLoader::DefaultState,
@@ -116,28 +113,26 @@ PrintQueueUi::PrintQueueUi(const KCupsPrinter &printer, QWidget *parent) :
     ui->jobsView->setItemDelegate(new NoSelectionRectDelegate(this));
     // sort by status column means the jobs will be sorted by the queue order
     ui->jobsView->sortByColumn(JobModel::ColStatus, Qt::AscendingOrder);
-    connect(ui->jobsView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(updateButtons()));
+    connect(ui->jobsView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &PrintQueueUi::updateButtons);
     connect(ui->jobsView, &QTreeView::customContextMenuRequested, this, &PrintQueueUi::showContextMenu);
     ui->jobsView->header()->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(ui->jobsView->header(), SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(showHeaderContextMenu(QPoint)));
+    connect(ui->jobsView->header(), &QHeaderView::customContextMenuRequested, this, &PrintQueueUi::showHeaderContextMenu);
 
     QHeaderView *header = ui->jobsView->header();
-    header->setResizeMode(QHeaderView::Interactive);
+    header->setSectionResizeMode(QHeaderView::Interactive);
     header->setStretchLastSection(false);
-    header->setResizeMode(JobModel::ColStatus,        QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColName,          QHeaderView::Stretch);
-    header->setResizeMode(JobModel::ColUser,          QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColCreated,       QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColCompleted,     QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColPages,         QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColProcessed,     QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColSize,          QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColStatusMessage, QHeaderView::ResizeToContents);
-    header->setResizeMode(JobModel::ColPrinter,       QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColStatus,        QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColName,          QHeaderView::Stretch);
+    header->setSectionResizeMode(JobModel::ColUser,          QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColCreated,       QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColCompleted,     QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColPages,         QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColProcessed,     QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColSize,          QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColStatusMessage, QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(JobModel::ColPrinter,       QHeaderView::ResizeToContents);
 
-    KConfigGroup printQueue(KSharedConfig::openConfig("print-manager"), "PrintQueue");
+    KConfigGroup printQueue(KSharedConfig::openConfig(QLatin1String("print-manager")), "PrintQueue");
     if (printQueue.hasKey("ColumnState")) {
         // restore the header state order
         header->restoreState(printQueue.readEntry("ColumnState", QByteArray()));
@@ -151,50 +146,43 @@ PrintQueueUi::PrintQueueUi(const KCupsPrinter &printer, QWidget *parent) :
     }
 
     // This is emitted when a printer is modified
-    connect(KCupsConnection::global(), SIGNAL(printerModified(QString,QString,QString,uint,QString,bool)), this,
-            SLOT(updatePrinter(QString,QString,QString,uint,QString,bool)));
+    connect(KCupsConnection::global(), &KCupsConnection::printerModified, this, &PrintQueueUi::updatePrinter);
 
     // This is emitted when a printer has it's state changed
-    connect(KCupsConnection::global(), SIGNAL(printerStateChanged(QString,QString,QString,uint,QString,bool)), this,
-            SLOT(updatePrinter(QString,QString,QString,uint,QString,bool)));
+    connect(KCupsConnection::global(), &KCupsConnection::printerStateChanged, this, &PrintQueueUi::updatePrinter);
 
     // This is emitted when a printer is stopped
-    connect(KCupsConnection::global(), SIGNAL(printerStopped(QString,QString,QString,uint,QString,bool)), this,
-            SLOT(updatePrinter(QString,QString,QString,uint,QString,bool)));
+    connect(KCupsConnection::global(), &KCupsConnection::printerStopped, this, &PrintQueueUi::updatePrinter);
 
     // This is emitted when a printer is restarted
-    connect(KCupsConnection::global(), SIGNAL(printerRestarted(QString,QString,QString,uint,QString,bool)), this,
-            SLOT(updatePrinter(QString,QString,QString,uint,QString,bool)));
+    connect(KCupsConnection::global(), &KCupsConnection::printerRestarted, this, &PrintQueueUi::updatePrinter);
 
     // This is emitted when a printer is shutdown
-    connect(KCupsConnection::global(), SIGNAL(printerShutdown(QString,QString,QString,uint,QString,bool)), this,
-            SLOT(updatePrinter(QString,QString,QString,uint,QString,bool)));
+    connect(KCupsConnection::global(), &KCupsConnection::printerShutdown, this, &PrintQueueUi::updatePrinter);
 
     // This is emitted when a printer is removed
-    connect(KCupsConnection::global(), SIGNAL(printerDeleted(QString,QString,QString,uint,QString,bool)), this,
-            SLOT(updatePrinter(QString,QString,QString,uint,QString,bool)));
+    connect(KCupsConnection::global(), &KCupsConnection::printerDeleted, this, &PrintQueueUi::updatePrinter);
 
     // This is emitted when a printer/queue is changed
     // Deprecated stuff that works better than the above
-    connect(KCupsConnection::global(), SIGNAL(rhPrinterAdded(QString)),
-            this, SLOT(updatePrinter(QString)));
+    connect(KCupsConnection::global(), &KCupsConnection::rhPrinterAdded, this, &PrintQueueUi::updatePrinterByName);
+    connect(KCupsConnection::global(), &KCupsConnection::rhPrinterRemoved, this, &PrintQueueUi::updatePrinterByName);
+    connect(KCupsConnection::global(), &KCupsConnection::rhQueueChanged, this, &PrintQueueUi::updatePrinterByName);
 
-    connect(KCupsConnection::global(), SIGNAL(rhPrinterRemoved(QString)),
-            this, SLOT(updatePrinter(QString)));
-
-    connect(KCupsConnection::global(), SIGNAL(rhQueueChanged(QString)),
-            this, SLOT(updatePrinter(QString)));
-
-    updatePrinter(m_destName);
+    updatePrinterByName(m_destName);
 
     // Restore the dialog size
-    KConfigGroup configGroup(KSharedConfig::openConfig("print-manager"), "PrintQueue");
+    KConfigGroup configGroup(KSharedConfig::openConfig(QLatin1String("print-manager")), "PrintQueue");
     KWindowConfig::restoreWindowSize(windowHandle(), configGroup);
+
+    auto delJobShortcut = new QShortcut(QKeySequence::Delete, ui->jobsView);
+    delJobShortcut->setContext(Qt::WidgetShortcut);
+    connect(delJobShortcut, &QShortcut::activated, this, &PrintQueueUi::cancelJob);
 }
 
 PrintQueueUi::~PrintQueueUi()
 {
-    KConfigGroup configGroup(KSharedConfig::openConfig("print-manager"), "PrintQueue");
+    KConfigGroup configGroup(KSharedConfig::openConfig(QLatin1String("print-manager")), "PrintQueue");
     // save the header state order
     configGroup.writeEntry("ColumnState", ui->jobsView->header()->saveState());
 
@@ -229,7 +217,7 @@ void PrintQueueUi::setState(int state, const QString &message)
         case KCupsPrinter::Idle:
             ui->statusL->setText(i18n("Printer ready"));
             ui->pausePrinterPB->setText(i18n("Pause Printer"));
-            ui->pausePrinterPB->setIcon(QIcon::fromTheme("media-playback-pause"));
+            ui->pausePrinterPB->setIcon(QIcon::fromTheme(QLatin1String("media-playback-pause")));
             break;
         case KCupsPrinter::Printing:
             if (!m_title.isNull()) {
@@ -240,14 +228,14 @@ void PrintQueueUi::setState(int state, const QString &message)
                     ui->statusL->setText(i18n("Printing '%1'", jobTitle));
                 }
                 ui->pausePrinterPB->setText(i18n("Pause Printer"));
-                ui->pausePrinterPB->setIcon(QIcon::fromTheme("media-playback-pause"));
+                ui->pausePrinterPB->setIcon(QIcon::fromTheme(QLatin1String("media-playback-pause")));
             }
             break;
         case KCupsPrinter::Stopped:
             m_printerPaused = true;
             ui->statusL->setText(i18n("Printer paused"));
             ui->pausePrinterPB->setText(i18n("Resume Printer"));
-            ui->pausePrinterPB->setIcon(QIcon::fromTheme("media-playback-start"));
+            ui->pausePrinterPB->setIcon(QIcon::fromTheme(QLatin1String("media-playback-start")));
             // create a paiter to paint the action icon over the key icon
             {
                 QPainter painter(&icon);
@@ -283,7 +271,8 @@ void PrintQueueUi::showContextMenu(const QPoint &point)
     selection = m_proxyModel->mapSelectionToSource(ui->jobsView->selectionModel()->selection());
     // if the selection is empty the user clicked on an empty space
     if (!selection.indexes().isEmpty()) {
-        foreach (const QModelIndex &index, selection.indexes()) {
+        const QModelIndexList indexes = selection.indexes();
+        for (const QModelIndex &index : indexes) {
             if (index.column() == 0 && index.flags() & Qt::ItemIsDragEnabled) {
                 // Found a move to item
                 moveTo = true;
@@ -293,24 +282,21 @@ void PrintQueueUi::showContextMenu(const QPoint &point)
         // if we can move a job create the menu
         if (moveTo) {
             // context menu
-            QMenu *menu = new QMenu(this);
+            auto menu = new QMenu(this);
             // move to menu
-            QMenu *moveToMenu = new QMenu(i18n("Move to"), this);
+            auto moveToMenu = new QMenu(i18n("Move to"), this);
 
             // get printers we can move to
             QPointer<KCupsRequest> request = new KCupsRequest;
-            QStringList attr;
-            attr << KCUPS_PRINTER_NAME;
-            attr << KCUPS_PRINTER_INFO;
-            request->getPrinters(attr);
+            request->getPrinters({ KCUPS_PRINTER_NAME, KCUPS_PRINTER_INFO });
             request->waitTillFinished();
             if (!request) {
                 return;
             }
-            KCupsPrinters printers = request->printers();
+            const KCupsPrinters printers = request->printers();
             request->deleteLater();
 
-            foreach (const KCupsPrinter &printer, printers) {
+            for (const KCupsPrinter &printer : printers) {
                 // If there is a printer and it's not the current one add it
                 // as a new destination
                 if (printer.name() != m_destName) {
@@ -337,12 +323,10 @@ void PrintQueueUi::showHeaderContextMenu(const QPoint &point)
 {
     // Displays a menu containing the header name, and
     // a check box to indicate if it's being shown
-    QMenu *menu = new QMenu(this);
+    auto menu = new QMenu(this);
     for (int i = 0; i < m_proxyModel->columnCount(); i++) {
-        QAction *action;
-        QString name;
-        name = m_proxyModel->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString();
-        action = menu->addAction(name);
+        auto name = m_proxyModel->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString();
+        QAction *action = menu->addAction(name);
         action->setCheckable(true);
         action->setChecked(!ui->jobsView->header()->isSectionHidden(i));
         action->setData(i);
@@ -359,7 +343,7 @@ void PrintQueueUi::showHeaderContextMenu(const QPoint &point)
     }
 }
 
-void PrintQueueUi::updatePrinter(const QString &printer)
+void PrintQueueUi::updatePrinterByName(const QString &printer)
 {
     qDebug() << printer << m_destName;
     if (printer != m_destName) {
@@ -367,13 +351,14 @@ void PrintQueueUi::updatePrinter(const QString &printer)
         return;
     }
 
-    QStringList attr;
-    attr << KCUPS_PRINTER_INFO;
-    attr << KCUPS_PRINTER_TYPE;
-    attr << KCUPS_PRINTER_STATE;
-    attr << KCUPS_PRINTER_STATE_MESSAGE;
+    const QStringList attr({
+                               KCUPS_PRINTER_INFO,
+                               KCUPS_PRINTER_TYPE,
+                               KCUPS_PRINTER_STATE,
+                               KCUPS_PRINTER_STATE_MESSAGE,
+                           });
 
-    KCupsRequest *request = new KCupsRequest;
+    auto request = new KCupsRequest;
     connect(request, &KCupsRequest::finished, this, &PrintQueueUi::getAttributesFinished);
     request->getPrinterAttributes(printer, m_isClass, attr);
 }
@@ -388,12 +373,11 @@ void PrintQueueUi::updatePrinter(const QString &text, const QString &printerUri,
     Q_UNUSED(printerIsAcceptingJobs)
     qDebug() << printerName << printerStateReasons;
 
-    updatePrinter(printerName);
+    updatePrinterByName(printerName);
 }
 
-void PrintQueueUi::getAttributesFinished()
+void PrintQueueUi::getAttributesFinished(KCupsRequest *request)
 {
-    KCupsRequest *request = qobject_cast<KCupsRequest *>(sender());
     qDebug() << request->hasError() << request->printers().isEmpty();
 
     if (request->hasError() || request->printers().isEmpty()) {
@@ -412,7 +396,7 @@ void PrintQueueUi::getAttributesFinished()
     if (printer.info().isEmpty()) {
         m_title = printer.name();
     } else {
-        m_title = printer.name() % QLatin1String(" - ") % printer.info();
+        m_title = printer.name() + QLatin1String(" - ") + printer.info();
     }
 
     // get printer-state
@@ -451,7 +435,8 @@ void PrintQueueUi::updateButtons()
     selection = m_proxyModel->mapSelectionToSource(ui->jobsView->selectionModel()->selection());
     // enable or disable the job action buttons if something is selected
     if (!selection.indexes().isEmpty()) {
-        foreach (const QModelIndex &index, selection.indexes()) {
+        const QModelIndexList indexes = selection.indexes();
+        for (const QModelIndex &index : indexes) {
             if (index.column() == 0) {
                 switch (static_cast<ipp_jstate_t>(index.data(JobModel::RoleJobState).toInt())) {
                     case IPP_JOB_CANCELED :
@@ -486,7 +471,8 @@ void PrintQueueUi::modifyJob(int action, const QString &destName)
     QItemSelection selection;
     // we need to map the selection to source to get the real indexes
     selection = m_proxyModel->mapSelectionToSource(ui->jobsView->selectionModel()->selection());
-    foreach (const QModelIndex &index, selection.indexes()) {
+    const QModelIndexList indexes = selection.indexes();
+    for (const QModelIndex &index : indexes) {
         if (index.column() == 0) {
             KCupsRequest *request;
             request = m_model->modifyJob(index.row(),
@@ -547,7 +533,7 @@ void PrintQueueUi::pausePrinter()
 
 void PrintQueueUi::configurePrinter()
 {
-    QProcess::startDetached("configure-printer", {m_destName});
+    QProcess::startDetached(QLatin1String("configure-printer"), {m_destName});
 }
 
 void PrintQueueUi::cancelJob()
@@ -594,26 +580,27 @@ void PrintQueueUi::setupButtons()
     // setup jobs buttons
 
     // cancel action
-    ui->cancelJobPB->setIcon(QIcon::fromTheme("dialog-cancel"));
+    ui->cancelJobPB->setIcon(QIcon::fromTheme(QLatin1String("dialog-cancel")));
 
     // hold job action
-    ui->holdJobPB->setIcon(QIcon::fromTheme("document-open-recent"));
+    ui->holdJobPB->setIcon(QIcon::fromTheme(QLatin1String("document-open-recent")));
 
     // resume job action
     // TODO we need a new icon
-    ui->resumeJobPB->setIcon(QIcon::fromTheme("media-playback-start"));
+    ui->resumeJobPB->setIcon(QIcon::fromTheme(QLatin1String("media-playback-start")));
 
-    ui->reprintPB->setIcon(QIcon::fromTheme("view-refresh"));
+    ui->reprintPB->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")));
 
-    ui->whichJobsCB->setItemIcon(0, QIcon::fromTheme("view-filter"));
-    ui->whichJobsCB->setItemIcon(1, QIcon::fromTheme("view-filter"));
-    ui->whichJobsCB->setItemIcon(2, QIcon::fromTheme("view-filter"));
+    const QIcon viewFilterIcon = QIcon::fromTheme(QLatin1String("view-filter"));
+    ui->whichJobsCB->setItemIcon(0, viewFilterIcon);
+    ui->whichJobsCB->setItemIcon(1, viewFilterIcon);
+    ui->whichJobsCB->setItemIcon(2, viewFilterIcon);
 
     // stop start printer
-    ui->pausePrinterPB->setIcon(QIcon::fromTheme("media-playback-pause"));
+    ui->pausePrinterPB->setIcon(QIcon::fromTheme(QLatin1String("media-playback-pause")));
 
     // configure printer
-    ui->configurePrinterPB->setIcon(QIcon::fromTheme("configure"));
+    ui->configurePrinterPB->setIcon(QIcon::fromTheme(QLatin1String("configure")));
 }
 
 void PrintQueueUi::closeEvent(QCloseEvent *event)
@@ -622,3 +609,5 @@ void PrintQueueUi::closeEvent(QCloseEvent *event)
     emit finished();
     QWidget::closeEvent(event);
 }
+
+#include "moc_PrintQueueUi.cpp"
